@@ -251,6 +251,29 @@ meta_param_paper_size_get_params			(MetaParam *mp)
 	deft.height-= deft.y;
 #undef set_int
 
+	/* note: decomposing area in three options orientation, origin and paper-size
+	 except these optoin to appear in this order. */
+	
+	/* ORIENTATION */
+	pspec = gs_param_spec_page_orientation ("page-orientation", N_("Page Orientation"), N_("Page orientation"),
+											GS_PARAM_GROUP_FORMAT,
+											GTK_PAGE_ORIENTATION_PORTRAIT,
+											G_PARAM_SPEC (mpps->tl_x)->flags);
+	gs_param_spec_set_index (pspec,
+							 gs_param_spec_get_index (G_PARAM_SPEC (mpps->tl_x))+2);
+	g_param_spec_set_qdata (pspec, GSANE_META_PARAM_QUARK, mp);
+	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (mp->gss), pspec);
+	
+	/* ORIG */
+	pspec = gs_param_spec_pointer ("origin", N_("Origin"), N_("Origin of scan window"),
+								   GS_PARAM_GROUP_PREVIEW,
+								   GNOME_TYPE_SCAN_PREVIEW_PLUGIN_AREA,
+								   G_PARAM_SPEC (mpps->tl_x)->flags);
+	gs_param_spec_set_index (pspec,
+							 gs_param_spec_get_index (G_PARAM_SPEC (mpps->tl_x))+1);
+	g_param_spec_set_qdata (pspec, GSANE_META_PARAM_QUARK, mp);
+	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (mp->gss), pspec);
+
 	/* PAPER SIZE */
 	static const gchar*names[] = {
 		GTK_PAPER_NAME_A5,
@@ -313,26 +336,7 @@ meta_param_paper_size_get_params			(MetaParam *mp)
 	g_param_spec_set_qdata (pspec, GSANE_META_PARAM_QUARK, mp);
 	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (mp->gss), pspec);
 
-	/* ORIG */
-	pspec = gs_param_spec_pointer ("origin", N_("Origin"), N_("Origin of scan window"),
-								   GS_PARAM_GROUP_PREVIEW,
-								   GNOME_TYPE_SCAN_PREVIEW_PLUGIN_AREA,
-								   G_PARAM_SPEC (mpps->tl_x)->flags);
-	gs_param_spec_set_index (pspec,
-							 gs_param_spec_get_index (G_PARAM_SPEC (mpps->tl_x))+1);
-	g_param_spec_set_qdata (pspec, GSANE_META_PARAM_QUARK, mp);
-	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (mp->gss), pspec);
 
-	/* ORIENTATION */
-	pspec = gs_param_spec_page_orientation ("page-orientation", N_("Page Orientation"), N_("Page orientation"),
-											GS_PARAM_GROUP_FORMAT,
-											GTK_PAGE_ORIENTATION_PORTRAIT,
-											G_PARAM_SPEC (mpps->tl_x)->flags);
-	gs_param_spec_set_index (pspec,
-							 gs_param_spec_get_index (G_PARAM_SPEC (mpps->tl_x))+2);
-	g_param_spec_set_qdata (pspec, GSANE_META_PARAM_QUARK, mp);
-	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (mp->gss), pspec);
-	
 	return TRUE;
 }
 
@@ -397,7 +401,7 @@ meta_param_paper_size_set_value			(MetaParam *mp, GParamSpec *spec, GValue *valu
 		}
 			
 		set_opt(br_x, x+w);
-		set_opt(br_y, x+h);
+		set_opt(br_y, y+h);
 	}
 	else if (g_str_equal (name, "origin")) {
 		mpps->origin = g_value_get_pointer (value);
@@ -582,9 +586,7 @@ meta_param_source_get_params (MetaParam *mp)
 		g_param_value_set_default (mps->source, default_value);
 		value = g_new0 (GValue, 1);
 		g_value_init (value, G_TYPE_STRING);
-		g_debug (G_STRLOC);
 		g_value_copy (default_value, value);
-		g_debug (G_STRLOC);
 		g_value_unset (default_value);
 		g_free (default_value);
 		
